#
# spec file for package python-grpcio-tools
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# PYTHON2 NOT SUPPORTED BY UPSTREAM
%define         skip_python2 1
%define         modname grpcio_tools
%{?sle15_python_module_pythons}
Name:           python-grpcio-tools
Version:        1.73.0
Release:        1.1
Summary:        Protobuf code generator for gRPC
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://grpc.io
Source:         https://files.pythonhosted.org/packages/source/g/grpcio-tools/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-grpcio >= %{version}
Requires:       python-protobuf >= 3.5.0.post1
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
# SECTION test requirements
BuildRequires:  %{python_module grpcio >= %{version}}
BuildRequires:  %{python_module protobuf >= 3.5.0.post1}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This package provides a python-based Protobuf code generator for gRPC.

%prep
%setup -q -n %{modname}-%{version}
# Drop a hashbang from anon-exec script
sed -i "1{/\/usr\/bin\/env python/d}" grpc_tools/protoc.py

%build
export GRPC_PYTHON_BUILD_WITH_CYTHON=true
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/python-grpc-tools-protoc
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%post
%python_install_alternative python-grpc-tools-protoc

%postun
%python_uninstall_alternative python-grpc-tools-protoc

%files %{python_files}
%doc README.rst
%python_alternative %{_bindir}/python-grpc-tools-protoc
%{python_sitearch}/grpc_tools
%{python_sitearch}/grpcio_tools-%{version}.dist-info

%changelog
* Sun Jun 15 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.73.0:
  * Pin Cython to 3.1.1 (gh#grpc/grpc#39609).
  * grpc_tools: make PythonGrpcGenerator handle dot . in proto
    paths the same way as native Generator/PyiGenerator
    (gh#grpc/grpc#39586).
- Package python-grpc-tools-protoc executable using
  update-alternatives.
* Sat May 10 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.72.0:
  * No python module specific changes documented.
- Changes from versions 1.70.0 through 1.71.1:
  * Undocumented.
* Fri Apr 11 2025 Antonello Tartamo <antonello.tartamo@suse.com>
- Updated to version 1.69.0
  * [Build] Override MACOSX_DEPLOYMENT_TARGET for gRPC Python. (#37997)
* Sun Dec 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.68.1:
  * No Python specific changes.
- Changes from version 1.68.0:
  * Add templating and support for Python 3.13
    (gh#grpc/grpc#37643).
* Wed Nov 13 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.67.1:
  * Minor bug fix release.
- Changes from version 1.67.0:
  * Add templating and support for Python 3.13
    (gh#grpc/grpc##37643).
  * Change warning to RuntimeError for version incompatibility
    (gh#grpc/grpc##37466).
  * Fix: reflection returns original_request
    (gh#grpc/grpc##36944).
* Wed Jul 17 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.65.0:
  * [Python O11y] Implement CSM observability for Python
    (gh#grpc/grpc#36557).
  * [Python AIO] Return EOF from UnaryStreamCall.read() as
    documented (gh#grpc/grpc#36660).
  * [Python Otel] Deprecate target_attribute_filter
    (gh#grpc/grpc#36697).
  * [Python Server] Remove abstractmethod notation for
    add_registered_method_handlers (gh#grpc/grpc#36684).
- Tests no longer work due to missing modules, disable %%check.
* Tue Apr 23 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.62.2:
  * [Fix Python Deadlock] Guard
    grpc_google_default_credentials_create with nogil
* Wed Mar 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.62.1:
  * This release contains refinements, improvements, and bug
    fixes.
* Fri Feb 23 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.62.0:
  * [Python AIO] Handle DeprecationWarnings when get current loop
    (gh#grpc/grpc#35583).
  * [Python AIO] Raise resource_exhausted error in case of
    concurrent RPC limit exceeded (gh#grpc/grpc#35376).
  * [Python O11y] Build and distrib O11y package
    (gh#grpc/grpc#35578).
  * [Python setuptools] Import error from distutils for lower
    version of setuptools (gh#grpc/grpc#35561).
* Sun Feb 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.60.1:
  * Revert change to print backtrace in server
* Fri Dec 15 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.60.0:
  * No python specific changes.
* Tue Oct 31 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.59.2:
  * No python specific changes.
* Sat Sep 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.59.0:
  * [Python 3.12] Support Python 3.12 (gh#grpc/grpc#34398).
  * [Python 3.12] Deprecate distutil (gh#grpc/grpc#34186).
* Sun Sep 17 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.58.0:
  * [Bazel] Enable grpcio-reflection to be used via Bazel
    (gh#grpc/grpc#31013).
  * [packaging] Publish xds-protos as part of the standard package
    pipeline (gh#grpc/grpc#33797).
* Wed Aug 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.57.0:
  * [posix] Enable systemd sockets for libsystemd>=233
    (gh#grpc/grpc#32671).
  * [python O11Y] Initial Implementation (gh#grpc/grpc#32974).
- Build with Cython.
* Sat Aug  5 2023 munix9@googlemail.com
- Update to version 1.56.2:
  * [WRR] backport (gh#grpc/grpc#33694) to 1.56 (gh#grpc/grpc#33698)
  * [backport][iomgr][EventEngine] Improve server handling of
    file descriptor exhaustion (gh#grpc/grpc#33667)
- Switch build to pip/wheel.
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
- Upstream only supports python >= 3.7, so adjust BuildRequires
  accordingly.
* Fri Jun 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.56.0:
  * [aio types] Fix some grpc.aio python types
    (gh#grpc/grpc#32475).
* Sat Jun 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.55.0:
  * [EventEngine] Disable EventEngine polling in gRPC Python
    (gh#grpc/grpc#33279) (gh#grpc/grpc#33320).
  * [Bazel Python3.11] Update Bazel dependencies for Python 3.11
    (gh#grpc/grpc#33318) (gh#grpc/grpc#33319).
* Fri Apr 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.54.0:
  * Fix DeprecationWarning when calling asyncio.get_event_loop()
    (gh#grpc/grpc#32533).
  * Remove references to deprecated syntax field
    (gh#grpc/grpc#32497).
* Mon Dec  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.51.1:
  * No Linux specific changes.
- Changes from version 1.51.0:
  * Fix lack of cooldown between poll attempts
    (gh#grpc/grpc#31550).
  * Remove enum and future (gh#grpc/grpc#31381).
  * [Remove Six] Remove dependency on six (gh#grpc/grpc#31340).
  * Update xds-protos package to pull in protobuf 4.X
    (gh#grpc/grpc#31113).
* Mon Oct 31 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.50.0:
  * No specific changes to tools.
* Sat Oct 15 2022 Michael Ströder <michael@stroeder.com>
- Update to version 1.49.1:
  * Support Python 3.11. (#30818)
  * Add type stub generation support to grpcio-tools. (#30498)
* Thu Sep  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.48.0:
  * [Aio] Ensure Core channel closes when deallocated
    [gh#grpc/grpc#29797].
  * [Aio] Fix the wait_for_termination return value
    [gh#grpc/grpc#29795].
* Tue Jun 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.46.3:
  * No tools specific updates, but sync with python-grpcio.
* Fri May  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.46.0:
  * Add Python GCF Distribtest [gh#grpc/grpc#29303].
  * Add Python Reflection Client [gh#grpc/grpc#29085].
  * Revert "Fix prefork handler register's default behavior"
    [gh#grpc/grpc#29229].
  * Fix prefork handler register's default behavior
    [gh#grpc/grpc#29103].
  * Fix fetching CXX variable in setup.py [gh#grpc/grpc#28873].
* Sat Apr 23 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.45.0:
  * Reimplement Gevent Integration [gh#grpc/grpc#28276].
  * Support musllinux binary wheels on x64 and x86
    [gh#grpc/grpc#28092].
  * Increase the Python protobuf requirement to >=3.12.0
    [gh#grpc/grpc#28604].
* Sat Feb 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.44.0:
  * Add python async example for hellostreamingworld using
    generator (gh#grpc/grpc#27343).
  * Disable __wrap_memcpy hack for Python builds
    (gh#grpc/grpc#28410).
  * Bump Bazel Python Cython dependency to 0.29.26
    (gh#grpc/grpc#28398).
  * Fix libatomic linking on Raspberry Pi OS Bullseye
    (gh#grpc/grpc#28041).
  * Allow generated proto sources in remote repositories for
    py_proto_library (gh#grpc/grpc#28103).
* Wed Feb  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.43.0:
  * [Aio] Validate the input type for set_trailing_metadata and
    abort (gh#grpc/grpc#27958).
* Thu Oct 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.41.0:
  * Add Python 3.10 support and drop 3.5 (gh#grpc/grpc#26074).
  * [Aio] Remove custom IO manager support (gh#grpc/grpc#27090).
* Wed Aug  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.39.0:
  * Python AIO: Match continuation typing on Interceptors
    (gh#grpc/grpc#26500).
  * Workaround #26279 by publishing manylinux_2_24 wheels instead
    of manylinux2014 on aarch64 (gh#grpc/grpc#26430).
  * Fix zlib unistd.h import problem (gh#grpc/grpc#26374).
  * Handle gevent exception in gevent poller (gh#grpc/grpc#26058).
* Wed Jun 30 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.38.1:
  * Backport gh#grpc/grpc#26430 and gh#grpc/grpc#26435 to v1.38.x
    (gh#grpc/grpc#26436).
* Sun May 23 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.38.0:
  * Add grpcio-admin Python package (gh#grpc/grpc#26166).
  * Add CSDS API to Python (gh#grpc/grpc#26114).
  * Expose code and details from context on the server side
    (gh#grpc/grpc#25457).
  * Explicitly import importlib.abc; required on Python 3.10.
    Fixes #26062 (gh#grpc/grpc#26083).
  * Fix potential deadlock on the GIL in AuthMetdataPlugin
    (gh#grpc/grpc#26009).
  * Introduce new Python package "xds_protos"
    (gh#grpc/grpc#25975).
  * Remove async mark for set_trailing_metadata interface
    (gh#grpc/grpc#25814).
* Sat May  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.37.1:
  * No user visible changes.
- Changes from version 1.37.0:
  * Clarify Guarantees about grpc.Future Interface
    (gh#grpc/grpc#25383).
  * [Aio] Add time_remaining method to ServicerContext
    (gh#grpc/grpc#25719).
  * Standardize all environment variable boolean configuration in
    python's setup.py (gh#grpc/grpc#25444).
  * Fix Signal Safety Issue (gh#grpc/grpc#25394).
* Thu Mar  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.36.1:
  * Core: back-port: add env var protection for google-c2p
    resolver (gh#grpc/grpc#25569).
* Thu Feb 25 2021 munix9@googlemail.com
- Update to version 1.35.0:
  * Implement Python Client and Server xDS Creds.
    (gh#grpc/grpc#25365)
  * Add %%define _lto_cflags %%{nil} (boo#1182659) (rh#1893533)
* Wed Jan 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.34.1:
  * Backport "Lazily import grpc_tools when using runtime
    stub/message generation" to 1.34.x (gh#grpc/grpc#25011).
- Changes from version 1.34.0:
  * Incur setuptools as an dependency for grpcio_tools
    (gh#grpc/grpc#24752).
  * Stop the spamming log generated by ctrl-c for AsyncIO server
    (gh#grpc/grpc#24718).
  * [gRPC Easy] Make Well-Known Types Available to Runtime
    Protos.(#24478)
  * Make Python 2 an optional dependency for Bazel build
    (gh#grpc/grpc#24407).
  * [Linux] [macOS] Support pre-compiled Python 3.9 wheels
    (gh#grpc/grpc#24356).
- Use pytest for testing; add BuildRequires: python-pytest.
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.33.2:
  * Make version check for importlib.abc in grpcio-tools more
    stringent (gh#grpc/grpc#24098).
* Wed Oct 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.33.1:
  * No release documentation.
- Adjust BuildRequires and Requires on python-grpcio to ensure
  version lock-in.
* Wed Jul 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
